@@ -22,7 +22,7 @@ use Config;
 use FindBinNew qw($Bin $Script);
 FindBinNew::again();
 
-our $VERSION = '0.041'; # VERSION
+our $VERSION = '0.042'; # VERSION
 
 has 'cmd' => (
   is       => 'rw',
@@ -248,7 +248,7 @@ sub run {
   };
 
   if ( $exit != 0 ) {
-    confess "[SUBMIT_ERROR] Could not submit job:\n$stdout$stderr";
+    die "[SUBMIT_ERROR] Could not submit job:\n$stdout$stderr";
   }
 
   $stdout =~ /^Your\s*job(-array)?\s*(\d+)/;
