@@ -8,15 +8,14 @@ use Carp;
 use Bio::Grid::Run::SGE;
 use Bio::Grid::Run::SGE::Master;
 use Data::Dumper;
-use File::Slurp;
+use Bio::Gonzales::Util::File qw/slurpc/;
 
 run_job(
     {
         task => sub {
             my ( $c, $result_prefix, $cmd_in_file ) = @_;
 
-            my $cmd = (read_file($cmd_in_file))[0];
-            chomp $cmd;
+            my $cmd = (slurpc($cmd_in_file))[0];
             INFO("running $cmd");
             my $success = my_sys_non_fatal($cmd);
 
